==> haskell-http3-0.0.1-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http3
version:              0.0.1
visibility:           public
id:                   http3-0.0.1-DSMn4Nd5Tit7xYf66LMWho
key:                  http3-0.0.1-DSMn4Nd5Tit7xYf66LMWho
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http3
synopsis:             HTTP/3 library
description:          HTTP/3 library including frames, QPACK, client and server.
category:             Network
abi:                  d1a5d52ddf9f4d89a56e73b1372a464b
exposed:              True
exposed-modules:
    Network.HQ.Client Network.HQ.Server Network.HTTP3.Client
    Network.HTTP3.Internal Network.HTTP3.Server Network.QPACK
    Network.QPACK.Internal

hidden-modules:
    Imports Network.HTTP3.Config Network.HTTP3.Context
    Network.HTTP3.Control Network.HTTP3.Error Network.HTTP3.Frame
    Network.HTTP3.Recv Network.HTTP3.Send Network.HTTP3.Settings
    Network.HTTP3.Stream Network.QPACK.Error Network.QPACK.HeaderBlock
    Network.QPACK.HeaderBlock.Decode Network.QPACK.HeaderBlock.Encode
    Network.QPACK.HeaderBlock.Prefix Network.QPACK.Instruction
    Network.QPACK.Table Network.QPACK.Table.Dynamic
    Network.QPACK.Table.RevIndex Network.QPACK.Table.Static
    Network.QPACK.Token Network.QPACK.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/http3-0.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/http3-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http3
hs-libraries:         HShttp3-0.0.1-DSMn4Nd5Tit7xYf66LMWho
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-9JCn8u65C4KCy9Nj55YpX7 containers-0.6.4.1
    http-types-0.12.3-8BMv0HmHQ5EvyizV19nIJ
    http2-3.0.3-9HHf8HQYAef315cysRu5oF
    network-3.1.3.0-IxZPNYPUmWN2rsUdI57YrX
    network-byte-order-0.1.6-J03wjpOipuOKp19CkwfKw4
    quic-0.1.2-K0FxHW66WAFIvZ7KQMWj74
    sockaddr-0.0.1-KsHuVp0yf6f1iYLSKVNScL stm-2.5.0.0
    time-manager-0.0.0-C5RW75MsQhgC7Gr53f5jvn
    unliftio-0.2.24.0-Cgo9TcQdeeWIqND7TVzpAA

haddock-interfaces:   /usr/share/doc/haskell-http3/html/http3.haddock
haddock-html:         /usr/share/doc/haskell-http3/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http3-0.0.1-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http3
version:              0.0.1
visibility:           public
id:                   http3-0.0.1-LOGIBog28F34XqFjltqV7k
key:                  http3-0.0.1-LOGIBog28F34XqFjltqV7k
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http3
synopsis:             HTTP/3 library
description:          HTTP/3 library including frames, QPACK, client and server.
category:             Network
abi:                  11dcd3e7575a31f8e916758fdc4c4d6a
exposed:              True
exposed-modules:
    Network.HQ.Client Network.HQ.Server Network.HTTP3.Client
    Network.HTTP3.Internal Network.HTTP3.Server Network.QPACK
    Network.QPACK.Internal

hidden-modules:
    Imports Network.HTTP3.Config Network.HTTP3.Context
    Network.HTTP3.Control Network.HTTP3.Error Network.HTTP3.Frame
    Network.HTTP3.Recv Network.HTTP3.Send Network.HTTP3.Settings
    Network.HTTP3.Stream Network.QPACK.Error Network.QPACK.HeaderBlock
    Network.QPACK.HeaderBlock.Decode Network.QPACK.HeaderBlock.Encode
    Network.QPACK.HeaderBlock.Prefix Network.QPACK.Instruction
    Network.QPACK.Table Network.QPACK.Table.Dynamic
    Network.QPACK.Table.RevIndex Network.QPACK.Table.Static
    Network.QPACK.Token Network.QPACK.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/http3-0.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/http3-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http3
hs-libraries:         HShttp3-0.0.1-LOGIBog28F34XqFjltqV7k
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-6HwZPMiOaK97nwlWoHY1Gb containers-0.6.4.1
    http-types-0.12.3-7JGGnEsHa6Z5SeBt4R3BBh
    http2-3.0.3-BVBX9RZo8rnHY48FnCiT8f
    network-3.1.4.0-23ur646Pq0yGXZtPd0ysVN
    network-byte-order-0.1.6-4w0Ht7TvMTA7sSxe3vBYAq
    quic-0.1.2-5zZaKCzsVeI8FAdlzlGMi0
    sockaddr-0.0.1-6hHsQ0VeMcMG1pEnWvWCsn stm-2.5.0.0
    time-manager-0.0.1-14ZYkszfadZ7Bc8J4OPcFc
    unliftio-0.2.24.0-AmSQrxMMLiq1AIGm31qi3q

haddock-interfaces:   /usr/share/doc/haskell-http3/html/http3.haddock
haddock-html:         /usr/share/doc/haskell-http3/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
